@@ -14,7 +14,7 @@ vibro() {
 	if grep -q "Call answered"; then
 	    if [ `cat /sys/devices/platform/gpio-switch/proximity/state` = "open" ]; then
 	       echo 150 > /sys/class/leds/twl4030:vibrator/brightness
-	       sleep 0.9
+	       gsleep 0.5
 	       echo 0 > /sys/class/leds/twl4030:vibrator/brightness
 	    fi
 	fi
